'use strict';

exports.__esModule = true;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _bunyan = require('bunyan');

var _bunyan2 = _interopRequireDefault(_bunyan);

/**
 * Instantiates a logger
 * @class
 */

var Logger = (function (_Bunyan) {
    _inherits(Logger, _Bunyan);

    /**
     * @constructs
     * @param opts <Object> passed straight through to bunyan.Logger
     */

    function Logger(opts) {
        _classCallCheck(this, Logger);

        _Bunyan.call(this, Object.assign({
            name: 'koa'
        }, opts || {}));
    }

    /**
     * Attaches the log instance to the koa instance
     * @returns generator function for koa middleware
     */

    Logger.prototype.attach = function attach() {
        var logger = this;
        return function* attachLogger(next) {
            if (this.logger) {
                console.warn('ctx.logger already exists');
                yield next;
                return;
            }

            this.logger = logger;

            yield next;
        };
    };

    /**
     * Basic request log middleware
     * @param opts <Object> options hash
     * @returns generator function for koa middleware
     */

    Logger.prototype.attachRequest = function attachRequest(opts) {
        var logger = this;

        return function* requestLogger(next) {
            var start = Date.now();

            logger.info({
                event: 'request',
                method: this.method,
                url: this.url
            });

            yield next;

            logger.info({
                event: 'response',
                method: this.method,
                url: this.originalUrl,
                status: this.status,
                delta: Date.now() - start
            });
        };
    };

    return Logger;
})(_bunyan2['default']);

exports['default'] = Logger;
module.exports = exports['default'];